<?php
/**
 * goldline functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package goldline
 */
define('GOLDLINE_PATH', get_template_directory_uri() ); 
define('GOLDLINE_PATH_SERVER_PATH', get_template_directory() );
define('GOLDLINE_AJAX_URL', admin_url('admin-ajax.php') );
if ( ! function_exists( 'goldline_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function goldline_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on goldline, use a find and replace
	 * to change 'goldline' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'goldline', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	if (function_exists('add_image_size')){
		add_image_size('blog-default','650','322',true);
		add_image_size('blog-list','217','243',true);
		add_image_size('blog-grid','358','285',true);
	}

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'goldline_menu' => esc_html__( 'Main Menu', 'goldline' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'goldline_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // goldline_setup
add_action( 'after_setup_theme', 'goldline_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function goldline_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'goldline_content_width', 640 );
}
add_action( 'after_setup_theme', 'goldline_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function goldline_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'goldline' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<div class="widget-title"><h4>',
		'after_title'   => '</h4></div>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar', 'goldline' ),
		'id'            => 'goldline_footer',
		'description'   => 'Widgets in this area will be shown in the footer.',
		'before_widget' => '<div class="col-lg-4 col-md-4 col-sm-6"><div class="gl_footer_data widget">',
		'after_widget'  => '</div></div>',
		'before_title'  => '<h2>',
		'after_title'   => '</h2>',
	) ); 
}
add_action( 'widgets_init', 'goldline_widgets_init' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Load Goldline Theme Option File.
 */
require get_template_directory() . '/include/theme_option/framework.php';
require get_template_directory() . '/include/theme_option/themeoption-config.php';

/**  
 * Load Goldline file.
 */ 
require get_template_directory() . '/include/theme_plugin/goldline-plugin-activate-config.php';
require get_template_directory() . '/include/goldline-enqueue.php';
require get_template_directory() . '/include/goldline_resizer.php';
require get_template_directory() . '/include/goldline-functions.php';
